==> nomachine-8.4.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXBroadcast.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXBroadcast::sendMessage{package NXBroadcast;no warnings;(my $ref_parameters
=shift (@_));if (($$ref_parameters{"\x6d\x65\x73\x73\x61\x67\x65"}eq (""))){
NXMsg::error ("\x65\x4d\x65\x73\x73\x61\x67\x65\x45\x6d\x70\x74\x79",
"\x4e\x58\x53\x68\x65\x6c\x6c");return ((0x09d6+ 2186-0x1260));}my ($uuid,$host,
$port);if (($$ref_parameters{"\x6e\x6f\x64\x65"}ne (""))){main::nxrequire (
"\x4e\x58\x4e\x6f\x64\x65\x73");(($uuid,$host,$port)=NXNodes::getNodeHostAndPort
 ($$ref_parameters{"\x6e\x6f\x64\x65"}));if (NXNodes::isErrorNotExistInDatabase 
($port)){NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x44\x6f\x65\x73\x4e\x6f\x74\x45\x78\x69\x73\x74"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6e\x6f\x64\x65"});return ((0x0e80+ 2766-0x194e));}elsif (
NXNodes::isErrorMoreThenOneHost ($port)){NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x50\x6f\x72\x74\x4d\x69\x73\x73\x69\x6e\x67"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74");return ((0x01e2+ 7645-0x1fbf));
}(my $nodeCheck=NXNodes::checkNodeExist ($uuid));if ((not (($nodeCheck=~ /^exist$/ )
))){NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x44\x6f\x65\x73\x4e\x6f\x74\x45\x78\x69\x73\x74"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6e\x6f\x64\x65"});return ((0x0108+ 8517-0x224d));}NXMsg::send_response (
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x54\x6f\x4e\x6f\x64\x65"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"},$$ref_parameters{"\x6e\x6f\x64\x65"});}else{
NXMsg::send_response (
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"});}(my (@sessionIds)=
NXSession2::listSessionsForBroadcast ($uuid));sub BEGIN{require Error;do{
"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}foreach my $id (
@sessionIds){&try (sub{NXShell::send_message_to_session ($id,$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"},"\x62\x72\x6f\x61\x64\x63\x61\x73\x74");},
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x66\x6f\x4d\x61\x6e\x61\x67\x65\x72\x3a\x3a\x52\x65\x63\x6f\x72\x64\x4e\x6f\x74\x46\x6f\x75\x6e\x64"
->catch (&with (sub{NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x53\x65\x73\x73\x69\x6f\x6e"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"},$id);return;})));}if (($$ref_parameters{
"\x6e\x6f\x64\x65"}ne (""))){NXMsg::info (
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b\x54\x6f\x4e\x6f\x64\x65"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6e\x6f\x64\x65"});}else{NXMsg::info (
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b",
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74");}return ((0x0c7b+ 3792-0x1b4a));
}package NXBroadcast;no warnings;NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
(0x1f34+ 1741-0x227d));NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x54\x6f\x4e\x6f\x64\x65"
,(0x18af+ 4264-0x25d3));NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b",
(0x0476+ 439-0x05af));NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b\x54\x6f\x4e\x6f\x64\x65"
,(0x17b4+ 217-0x180f));NXMsg::register_error (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x44\x6f\x65\x73\x4e\x6f\x74\x45\x78\x69\x73\x74"
,(0x0ae9+ 6009-0x206e));NXMsg::register_error (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x50\x6f\x72\x74\x4d\x69\x73\x73\x69\x6e\x67"
,(0x0d8a+ 594-0x0de8));NXMsg::register_error (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x53\x65\x73\x73\x69\x6f\x6e"
,(0x15fd+ 3664-0x2202));return ((0x015d+ 7525-0x1ec1));

==> nomachine-8.6.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXBroadcast.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXBroadcast::sendMessage{package NXBroadcast;no warnings;(my $ref_parameters
=shift (@_));if (($$ref_parameters{"\x6d\x65\x73\x73\x61\x67\x65"}eq (""))){
NXMsg::error ("\x65\x4d\x65\x73\x73\x61\x67\x65\x45\x6d\x70\x74\x79",
"\x4e\x58\x53\x68\x65\x6c\x6c");return ((0x1bb8+ 556-0x1de4));}my ($uuid,$host,
$port);if (($$ref_parameters{"\x6e\x6f\x64\x65"}ne (""))){main::nxrequire (
"\x4e\x58\x4e\x6f\x64\x65\x73");(($uuid,$host,$port)=NXNodes::getNodeHostAndPort
 ($$ref_parameters{"\x6e\x6f\x64\x65"}));if (NXNodes::isErrorNotExistInDatabase 
($port)){NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x44\x6f\x65\x73\x4e\x6f\x74\x45\x78\x69\x73\x74"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6e\x6f\x64\x65"});return ((0x0d93+ 4884-0x20a7));}elsif (
NXNodes::isErrorMoreThenOneHost ($port)){NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x50\x6f\x72\x74\x4d\x69\x73\x73\x69\x6e\x67"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74");return ((0x10fa+ 820-0x142e));}
(my $nodeCheck=NXNodes::checkNodeExist ($uuid));if ((not (($nodeCheck=~ /^exist$/ )
))){NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x44\x6f\x65\x73\x4e\x6f\x74\x45\x78\x69\x73\x74"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6e\x6f\x64\x65"});return ((0x0785+ 3571-0x1578));}NXMsg::send_response (
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x54\x6f\x4e\x6f\x64\x65"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"},$$ref_parameters{"\x6e\x6f\x64\x65"});}else{
NXMsg::send_response (
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"});}(my (@sessionIds)=
NXSession2::listSessionsForBroadcast ($uuid));sub BEGIN{require Error;do{
"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}foreach my $id (
@sessionIds){&try (sub{NXShell::send_message_to_session ($id,$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"},"\x62\x72\x6f\x61\x64\x63\x61\x73\x74");},
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x66\x6f\x4d\x61\x6e\x61\x67\x65\x72\x3a\x3a\x52\x65\x63\x6f\x72\x64\x4e\x6f\x74\x46\x6f\x75\x6e\x64"
->catch (&with (sub{NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x53\x65\x73\x73\x69\x6f\x6e"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"},$id);return;})));}if (($$ref_parameters{
"\x6e\x6f\x64\x65"}ne (""))){NXMsg::info (
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b\x54\x6f\x4e\x6f\x64\x65"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6e\x6f\x64\x65"});}else{NXMsg::info (
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b",
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74");}return ((0x0e4a+ 2275-0x172c));
}package NXBroadcast;no warnings;NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
(0x1abf+ 1237-0x1c10));NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x54\x6f\x4e\x6f\x64\x65"
,(0x17f3+ 332-0x15bb));NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b",
(0x02a1+ 661-0x04b8));NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b\x54\x6f\x4e\x6f\x64\x65"
,(0x1327+ 1057-0x16ca));NXMsg::register_error (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x44\x6f\x65\x73\x4e\x6f\x74\x45\x78\x69\x73\x74"
,(0x0a7d+ 5613-0x1e76));NXMsg::register_error (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x50\x6f\x72\x74\x4d\x69\x73\x73\x69\x6e\x67"
,(0x0b77+ 5834-0x204d));NXMsg::register_error (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x53\x65\x73\x73\x69\x6f\x6e"
,(0x1cb0+ 1114-0x1ebf));return ((0x036a+ 9117-0x2706));
